@@ -3,7 +3,7 @@ from pydantic import Field, BaseModel
 from ..company.assets.ai_agents.related_asset import RelatedChattyAsset
 
 
-class RelatedAssetsMixin(BaseModel):
+class RelatedAssetsMixin:
     """Protocol for models that have related chatty assets"""
     related_assets: List[RelatedChattyAsset] = Field(default_factory=list)
 
