@@ -14,6 +14,7 @@ from .continuous_conversation import ContinuousConversation
 from .scheduled_messages import ScheduledMessages
 from .flow_link_state import FlowStateAssignedToChat
 from ..company.assets.chat_assets import ChattyAIAgentAssignedToChat
+from ..messages.chatty_messages.base.message_draft import MessageDraft
 
 from .time_left import TimeLeft
 import json
@@ -26,7 +27,6 @@ if TYPE_CHECKING:
     from ..company.assets.sale import Sale
     from ..company.assets.contact_point import ContactPoint
 
-
 class Chat(CompanyAssetModel):
     """
     Chat data model representing a conversation between a client and an agent.
@@ -43,7 +43,7 @@ class Chat(CompanyAssetModel):
     scheduled_messages: List[ScheduledMessages] = Field(default_factory=list)
     flow_states: List[FlowStateAssignedToChat] = Field(default_factory=list)
     chatty_ai_agent: Optional[ChattyAIAgentAssignedToChat] = Field(default=None, description="The id of the chatty ai agent that might or might not be assigned to the chat")
-
+    suggested_messages: List[MessageDraft] = Field(default_factory=list)
     model_config = ConfigDict(extra="ignore")
 
     @property
