@@ -1,7 +1,7 @@
-from pydantic import Field
+from pydantic import Field, BaseModel
 from letschatty.models.base_models.related_asset_mixin import RelatedAssetsMixin
 
-class ContextItem(RelatedAssetsMixin):
+class ContextItem(RelatedAssetsMixin, BaseModel):
     """Individual context item with title and content"""
     title: str = Field(..., description="Title of the context section")
     content: str = Field(..., description="Content of the context section")
