@@ -37,7 +37,10 @@ class ExecutionContext(BaseModel):
 
     def set_event_time(self, timestamp: datetime):
         """Set the time to use for event timestamps"""
-        self.event_time = timestamp
+        if self.event_time is None:
+            self.event_time = timestamp
+        else:
+            return
 
     @classmethod
     def default_for_automations(cls, source: Source) -> "ExecutionContext":
