@@ -159,4 +159,16 @@ class ResetAIAgentMessage(CustomException):
 
 class DatasetIDConversionsAPINotFound(NotFoundError):
     def __init__(self, message="Dataset ID conversions API not found", status_code=404, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class HumanInterventionRequired(CustomException):
+    def __init__(self, message="Human intervention required", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class PostponeFollowUp(CustomException):
+    def __init__(self, message="Follow up postponed", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class SmartFollowUpStrategyNotSet(CustomException):
+    def __init__(self, message="Smart follow up strategy not set", status_code=400, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
\ No newline at end of file
