@@ -13,8 +13,7 @@ from letschatty.models.company.assets.contact_point import ContactPoint
 from letschatty.models.chat.highlight import Highlight, HighlightRequestData
 from letschatty.models.chat.quality_scoring import QualityScore
 from letschatty.models.copilot.links import LinkItem
-from letschatty.models.chat.flow_link_state import FlowStateAssignedToChat
-
+from letschatty.models.chat.flow_link_state import FlowStateAssignedToChat, SmartFollowUpState
 from datetime import datetime
 from typing import Dict, Any, Optional, List, TYPE_CHECKING
 from letschatty.models.execution.execution import ExecutionContext
@@ -27,6 +26,7 @@ from ...models.chat.scheduled_messages import ScheduledMessageStatus
 from ...models.utils.types.identifier import StrObjectId
 from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted, ErrorToMantainSafety
 from ..factories.messages.central_notification_factory import CentralNotificationFactory
+from ...models.messages.chatty_messages.base.message_draft import MessageDraft
 from ...models.messages.chatty_messages.schema.chatty_content.content_central import CentralNotificationStatus
 from ...models.messages.chatty_messages.schema import ChattyContext
 from ...models.utils.types.message_types import MessageType
@@ -134,7 +134,7 @@ class ChatService:
         """
         Add a tag to the chat.
         """
-        if next((tag for tag in chat.client.tags if tag.asset_id == tag.id), None) is not None:
+        if next((assigned_tag for assigned_tag in chat.client.tags if assigned_tag.asset_id == tag.id), None) is not None:
             raise AssetAlreadyAssigned(f"Tag with id {tag.id} already assigned to chat {chat.id}")
         assigned_asset = AssignedAssetToChat(
             asset_type=ChatAssetType.TAG,
@@ -211,7 +211,11 @@ class ChatService:
         """
         Add a tag to the chat.
         """
-        state = FlowStateAssignedToChat.from_link(link, execution_context, description, last_incoming_message_id, next_call)
+        if flow.is_smart_follow_up:
+            current_smart_follow_up_state = next((state for state in chat.flow_states if state.is_smart_follow_up), None)
+            if current_smart_follow_up_state is not None:
+                raise AssetAlreadyAssigned(f"Smart follow up with id {link.flow_id} already assigned to chat {chat.id}")
+        state = FlowStateAssignedToChat.from_link(link=link, execution_context=execution_context, description=description, last_incoming_message_id=last_incoming_message_id, next_call=next_call, is_smart_follow_up=flow.is_smart_follow_up)
         if state in chat.flow_states:
             raise AssetAlreadyAssigned(f"Flow with id {link.flow_id} already assigned to chat {chat.id}")
         execution_context.set_event_time(state.assigned_at)
@@ -234,17 +238,22 @@ class ChatService:
             raise NotFoundError(message=f"Workflow with id {workflow_id} not found in chat {chat.id}")
 
     @staticmethod
-    def update_workflow_link(chat : Chat, workflow_id : StrObjectId, workflow_link: FlowStateAssignedToChat, flow:FlowPreview, execution_context: ExecutionContext) -> FlowStateAssignedToChat:
+    def update_workflow_link(chat : Chat, workflow_id : StrObjectId, workflow_link: FlowStateAssignedToChat, execution_context: ExecutionContext) -> FlowStateAssignedToChat:
         """
         Update a workflow link for the chat.
         """
         assigned_asset_to_remove = next(state for state in chat.flow_states if state.flow_id == workflow_id)
         chat.flow_states.remove(assigned_asset_to_remove)
         bisect.insort(chat.flow_states, workflow_link)
-        execution_context.set_event_time(workflow_link.assigned_at)
-        # ChatService.add_central_notification_from_text(chat=chat, body=f"Workflow {flow.title} actualizado en el chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.WORKFLOW_UPDATED)
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
         return workflow_link
 
+    @staticmethod
+    def get_smart_follow_up_state(chat : Chat) -> Optional[SmartFollowUpState]:
+        """
+        Get the smart follow up state for the chat.
+        """
+        return next((state for state in chat.flow_states if isinstance(state, SmartFollowUpState)), None)
 
     @staticmethod
     def create_sale(chat : Chat, execution_context: ExecutionContext, sale : Sale, product : Product) -> SaleAssignedToChat:
@@ -662,3 +671,23 @@ class ChatService:
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
         ChatService.add_central_notification_from_text(chat=chat, body=f"El chat fue desbloqueado por {execution_context.executor.name}", subtype=MessageSubtype.CHAT_UNBLOCKED)
         return chat
+
+    @staticmethod
+    def add_suggested_messages(chat: Chat, suggested_messages: List[MessageDraft], execution_context: ExecutionContext) -> Chat:
+        """
+        Add suggested messages to the chat.
+        """
+        chat.suggested_messages=suggested_messages
+        logger.debug(f"Added {len(suggested_messages)} suggested messages to chat {chat.id} #{chat.client.get_waid()}")
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        return chat
+
+    @staticmethod
+    def remove_suggested_messages(chat: Chat, execution_context: ExecutionContext) -> Chat:
+        """
+        Remove suggested messages from the chat.
+        """
+        chat.suggested_messages = []
+        logger.debug(f"Removed all suggested messages from chat {chat.id} #{chat.client.get_waid()}")
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        return chat
\ No newline at end of file
